function [exitFlag exitMsg netStruct] = ca_fixValue(netStruct, algorithmParameters, net2planParameters)

    % Algorithm for capacity assignment problems which puts a fix capacity
    % value for all links. It also eliminates the routing information
    %
    % PARAM: capacityValue | 10 | Capacity in Erlangs (greater than 0)

    capacityValue = str2double(algorithmParameters.capacityValue);
    assert(isfinite(capacityValue) && capacityValue > 0, '"capacityValue" must be greater than zero');

    % Assign same capacity value to each link
    E = size (netStruct.linkTable , 1);
    netStruct.linkCapacityInErlangs = capacityValue * ones (1,E);

    % Remove obsolote routing information
    netStruct = removeRoutingInformation(netStruct);

    exitFlag = 0;
    exitMsg = 'OK!';

end