function yesNo = isBidirectional(linkTable)

    % Check whether the topology is bidirectional: same number
	% of links between each node pair in both directions (assuming
	% multi-digraphs)
    %
    % Syntax: yesNo = isBidirectional(linkTable)
    %
    % Input parameters:
    % - linkTable (Ex2): A table in which each row represents
	%   the origin and the destination nodes of the link
    %
    % Output parameters:
    % - yesNo: '1' if is bidirectional, '0' if not

	%% Sanity check
	assert(isLinkTable(linkTable), 'A valid set of links is required');
		
	%% Check symmetry using adjacency matrix
	N = max(linkTable(:));
	adjacencyMatrix = linkTable2adjacencyMatrix(linkTable, N);
	yesNo = isequal(adjacencyMatrix, adjacencyMatrix');

end