function incidenceMatrix = linkTable2incidenceMatrix(linkTable, N)

    % Compute the incidence matrix from a link table of a multi-digraph
    %
    % Syntax: incidenceMatrix = linkTable2incidenceMatrix(linkTable, N)
    %
    % Input parameters:
    % - linkTable (Ex2): A table in which each row represents
	%   the origin and the destination nodes of the link
    % - N: Number of nodes in the topology
    %
    % Output parameters:
    % - adjacencyMatrix (NxN): An sparse matrix in which each position
    %   a_ij represents the number of links between nodes i and j

	%% Sanity checks
	assert(numel(N) == 1 && isfinite(N) && N == round(N) && N > 0, ...
		'Number of nodes must be greater than 0');
	assert(isLinkTable(linkTable, N), 'A valid set of links is required');

	% Compute incidence matrix
	E = size(linkTable,1);
	incidenceMatrix = sparse(N, E);
	incidenceMatrix(sub2ind([N E], linkTable(:,1), (1:E)')) = 1;
	incidenceMatrix(sub2ind([N E], linkTable(:,2), (1:E)')) = -1;
	
end