function delta_pe = seqLinksPerPath2linkOccupancyPerPath(pathList, E)

	% Function to convert a pathList into a PxE matrix in which each entry
	% (p,e) represents how many times p traverses link e
	%
	% Syntax: delta_pe = seqLinksPerPath2linkOccupancyPerPath(pathList, E)
	%
	% Input parameters:
	% - pathList {1xP}: Cell in which each entry is the sequence of links
	%   followed by path p
	% - E: Number of total links in the whole network
	%
	% Output parameters:
	% - delta_pe (PxE): Matrix in which each entry (p,e) represents 
	%   how many times p traverses link e

    %% Sanity checks
    assert(isPathList(pathList, E), 'A set of valid paths is required');
    
    %% Compute delta_pe
    P = numel(pathList);
    delta_pe = sparse(P, E);
    for pathId = 1:P
        delta_pe = delta_pe + accumarray([pathId * ones(1,numel(pathList{pathId})); pathList{pathId}]', 1, [P E], [], [], true);
    end
		
end