function sequenceOfNodes = sequenceOfLinks2sequenceOfNodes(linkTable, sequenceOfLinks)

	% Given a linkTable and a sequenceOfLinks, return the sequenceOfNodes
	% traversed
	%
	% Syntax: sequenceOfNodes = sequenceOfLinks2sequenceOfNodes(linkTable, sequenceOfLinks)
	%
	% Input parameters:
	% - linkTable (Ex2): Table in which each row represents the origin and destination
	%   node of the link
	% - sequenceOfLinks: Row vector with a feasible sequence of links
	%
	% Output parameters:
	% - sequenceOfNodes: Nodes traversed by sequenceOfLinks

	%% Sanity checks
	assert(isLinkTable(linkTable), 'A valid set of links is required');
	E = size(linkTable, 1);
	assert(~isempty(sequenceOfLinks) && all(isfinite(sequenceOfLinks(:))) && ndims(sequenceOfLinks) == 2 && ...
		size(sequenceOfLinks, 1) == 1 && all(sequenceOfLinks(:) > 0) && all(sequenceOfLinks(:) <= E), ...
		sprintf('sequenceOfLinks must be a valid row vector with each value in range [1, %d]', E));
	sourceNodes = linkTable(sequenceOfLinks, 1);
	destinationNodes = linkTable(sequenceOfLinks, 2);
	assert(isequal(sourceNodes(2:end), destinationNodes(1:end-1)), 'Sequence of links not feasible');
	
	%% Get sequenceOfNodes
	sequenceOfNodes = [sourceNodes; destinationNodes(end)]';

end